@@ -842,13 +842,13 @@ def conversation_context_menu_set(
 
 def file_create(
     type: FileType,
-    title: str,
+    title: Optional[str] = None,
     markdown: Optional[str] = None,
     uri: Optional[str] = None,
     thumbnail: Optional[Image] = None,
     lang: Optional[UserLang] = None,
     indexable: Optional[bool] = None,
-    ui: Optional[dict] = None,
+    page: Optional[dict] = None,
 ) -> File:
     """
     Create file
@@ -864,7 +864,7 @@ def file_create(
                 "thumbnail": thumbnail,
                 "lang": lang,
                 "indexable": indexable,
-                "ui": ui,
+                "page": page,
             },
         )
     )
@@ -875,10 +875,10 @@ def file_update(
     markdown: Optional[str] = None,
     title: Optional[str] = None,
     thumbnail: Optional[Image] = None,
-    ui: Optional[dict] = None,
+    page: Optional[dict] = None,
 ) -> None:
     """
-    Update file, only supported on markdown files
+    Update file, only supported on markdown & page files
     """
     call_no_return(
         "botCodeFileUpdate",
@@ -887,7 +887,7 @@ def file_update(
             "title": title,
             "markdown": markdown,
             "thumbnail": thumbnail,
-            "ui": ui,
+            "page": page,
         },
     )
 
